@@ -1,6 +1,8 @@
+from utils.Browser import Browser
 from utils.cache import cache
 from utils.Color import Color
 from utils.Dict import Dict
+from utils.Directory import Directory
 from utils.File import CSVFile, File, JSONFile, TSVFile, XSVFile, Zip
 from utils.Git import Git
 from utils.GoogleMaps import GoogleMaps
@@ -11,5 +13,5 @@ from utils.Table import Table, TableRow
 from utils.time import (DAYS_IN, SECONDS_IN, TIME_FORMAT_DATE,
                         TIME_FORMAT_DATE_ID, TIME_FORMAT_TIME,
                         TIME_FORMAT_TIME_ID, TIMEZONE_OFFSET, Time, TimeDelta,
-                        TimeFormat, TimeUnit)
+                        TimeFormat, TimeUnit, get_date_id, get_time_id)
 from utils.www import WWW
