@@ -5,8 +5,10 @@ import logging
 
 import tweepy
 
-from utils import timex
 from utils.cache import cache
+from utils.time.Time import Time
+from utils.time.TimeFormat import TimeFormat
+from utils.time.TimeUnit import SECONDS_IN
 
 MAX_LEN_TWEET = 280
 MAX_MEDIA_FILES = 4
@@ -47,7 +49,9 @@ def _upload_media(api, image_files):
 
 
 def _update_profile_description(api):
-    date_with_timezone = timex.format_current_date_with_timezone()
+    date_with_timezone = TimeFormat('YYYY-MM-DD HH:mm:ss Z').stringify(
+        Time.now()
+    )
     description = 'Automatically updated at {date_with_timezone}'.format(
         date_with_timezone=date_with_timezone
     )
@@ -70,12 +74,6 @@ class Twitter:
             auth = tweepy.OAuthHandler(twtr_api_key, twtr_api_secret_key)
             auth.set_access_token(twtr_access_token, twtr_access_token_secret)
             self.api = tweepy.API(auth)
-            api_me = self.api.me()
-            log.info(
-                'Created Twitter for @%s (%s).',
-                api_me.screen_name,
-                api_me.id_str,
-            )
         else:
             log.error('Missing twitter API Key etc. Cannot create Twitter.')
             self.api = None
@@ -169,7 +167,7 @@ class Twitter:
             log.error('Missing API. Cannot search')
             return None
 
-        @cache('utils.twitter', timex.SECONDS_IN.YEAR)
+        @cache('utils.twitter', SECONDS_IN.YEAR)
         def fallback(query_text=query_text):
             log.info('Inner call')
             results_list = self.api.search_users(query_text)
