@@ -1,7 +1,8 @@
 import xml.dom.minidom as minidom
 import xml.etree.ElementTree as ElementTree
 
-from utils import dt, filex
+from utils import String
+from utils.File import File
 
 FONT_FAMILY = 'sans-serif'
 DEFAULT_ATTRIB_MAP = {
@@ -23,7 +24,7 @@ def style(**kwargs):
         list(
             map(
                 lambda item: '%s:%s;'
-                % (dt.to_kebab(str(item[0])), str(item[1])),
+                % (String(str(item[0])).kebab, str(item[1])),
                 kwargs.items(),
             )
         )
@@ -87,4 +88,4 @@ class _:
         return self.__str__()
 
     def store(self, xml_file):
-        filex.write(xml_file, str(self))
+        File(xml_file).write(str(self))
